@@ -25,3 +25,5 @@ pub mod vcd_probe;
 pub mod verilog_gen;
 pub mod verilog_visitor;
 pub mod yosys;
+pub mod check_logic_loops;
+pub mod check_error;
