@@ -6,6 +6,8 @@ use crate::core::check_connected::check_connected;
 use crate::core::vcd_probe::{write_vcd_change, write_vcd_dump, write_vcd_header};
 use std::io::Write;
 use std::thread::JoinHandle;
+use crate::core::check_error::CheckError;
+use crate::core::check_logic_loops::check_logic_loops;
 
 pub fn simulate<B: Block>(uut: &mut B, max_iters: usize) -> bool {
     for _ in 0..max_iters {
@@ -17,12 +19,19 @@ pub fn simulate<B: Block>(uut: &mut B, max_iters: usize) -> bool {
     false
 }
 
-#[derive(Copy, Clone, Debug, PartialEq)]
+#[derive(Clone, Debug, PartialEq)]
 pub enum SimError {
     SimTerminated,
     MaxTimeReached,
     SimHalted,
     FailedToConverge,
+    Check(CheckError),
+}
+
+impl From<CheckError> for SimError {
+    fn from(x: CheckError) -> Self {
+        SimError::Check(x)
+    }
 }
 
 impl From<RecvError> for SimError {
@@ -220,7 +229,8 @@ impl<T: Send + 'static + Block> Simulation<T> {
         }))
     }
     pub fn run(&mut self, mut x: Box<T>, max_time: u64) -> Result<()> {
-        check_connected(x.as_mut());
+        check_connected(x.as_mut())?;
+        check_logic_loops(x.as_mut())?;
         // First initialize the workers.
         for id in 0..self.workers.len() {
             x = self.dispatch(id, x)?;
@@ -252,7 +262,8 @@ impl<T: Send + 'static + Block> Simulation<T> {
         result
     }
     pub fn run_traced<W: Write>(&mut self, mut x: Box<T>, max_time: u64, trace: W) -> Result<()> {
-        check_connected(x.as_mut());
+        check_connected(x.as_mut())?;
+        check_logic_loops(x.as_mut())?;
         let mut vcd = write_vcd_header(trace, x.as_ref());
         // First initialize the workers.
         for id in 0..self.workers.len() {
