@@ -1,7 +1,6 @@
 use rust_hdl::bsp::ok_core::prelude::OpalKellyBSP;
 use rust_hdl::bsp::ok_xem6010::XEM6010;
 use rust_hdl::core::prelude::*;
-use rust_hdl::widgets::prelude::*;
 
 mod test_common;
 #[cfg(feature = "frontpanel")]
@@ -14,5 +13,5 @@ fn test_opalkelly_xem_6010_synth_pipe_ram() {
     uut.hi.link_connect_dest();
     uut.connect_all();
     XEM6010::synth(uut, target_path!("xem_6010/pipe_ram"));
-    test_opalkelly_pipe_ram_runtime(target_path!("xem_6010/pipe_ram/top.bit"));
+    test_opalkelly_pipe_ram_runtime(target_path!("xem_6010/pipe_ram/top.bit")).unwrap();
 }
