@@ -3,15 +3,10 @@ use rust_hdl::core::prelude::*;
 use rust_hdl::widgets::prelude::*;
 mod test_common;
 
-use rust_hdl::bsp::ok_xem7010::pins::{xem_7010_leds, xem_7010_neg_clock, xem_7010_pos_clock};
 use rust_hdl::bsp::ok_xem7010::sys_clock::OpalKellySystemClock7;
 use rust_hdl::bsp::ok_xem7010::XEM7010;
 #[cfg(feature = "frontpanel")]
-use rust_hdl_ok_frontpanel_sys::{make_u16_buffer, OkError};
-#[cfg(feature = "frontpanel")]
 use test_common::pipe::*;
-#[cfg(feature = "frontpanel")]
-use test_common::tools::*;
 
 declare_async_fifo!(OKTestAFIFO, Bits<16>, 256, 1);
 
